@@ -6,13 +6,16 @@ Flavor backend can deploy particular flavor locally to generate predictions, dep
 REST api endpoint, or build a docker image for serving the model locally or remotely.
 Not all flavors have a flavor backend.
 """
-import mlflow.pyfunc as pyfunc
+from mlflow import pyfunc
 
 
 def get_flavor_backend(model, build_docker=True, **kwargs):
     from mlflow.pyfunc.backend import PyFuncBackend
     from mlflow.rfunc.backend import RFuncBackend
 
+    if not model:
+        return pyfunc.FLAVOR_NAME, PyFuncBackend({}, **kwargs)
+
     _flavor_backends = {pyfunc.FLAVOR_NAME: PyFuncBackend, "crate": RFuncBackend}
     for flavor_name, flavor_config in model.flavors.items():
         if flavor_name in _flavor_backends:
