@@ -163,15 +163,21 @@ class RestStore(AbstractStore):
         response_proto = self._call_endpoint(GetRun, req_body)
         return Run.from_proto(response_proto.run)
 
-    def update_run_info(self, run_id, run_status, end_time):
+    def update_run_info(self, run_id, run_status, end_time, run_name):
         """Updates the metadata of the specified run."""
         req_body = message_to_json(
-            UpdateRun(run_uuid=run_id, run_id=run_id, status=run_status, end_time=end_time)
+            UpdateRun(
+                run_uuid=run_id,
+                run_id=run_id,
+                status=run_status,
+                end_time=end_time,
+                run_name=run_name,
+            )
         )
         response_proto = self._call_endpoint(UpdateRun, req_body)
         return RunInfo.from_proto(response_proto.run_info)
 
-    def create_run(self, experiment_id, user_id, start_time, tags):
+    def create_run(self, experiment_id, user_id, start_time, tags, run_name):
         """
         Create a run under the specified experiment ID, setting the run's status to "RUNNING"
         and the start time to the current time.
@@ -180,6 +186,7 @@ class RestStore(AbstractStore):
         :param user_id: ID of the user launching this run
         :param start_time: timestamp of the initialization of the run
         :param tags: tags to apply to this run at initialization
+        :param name: Name of this run.
 
         :return: The created Run object
         """
@@ -191,6 +198,7 @@ class RestStore(AbstractStore):
                 user_id=user_id,
                 start_time=start_time,
                 tags=tag_protos,
+                run_name=run_name,
             )
         )
         response_proto = self._call_endpoint(CreateRun, req_body)
