@@ -1,7 +1,11 @@
 import os
-import sys
 from functools import partial
+import logging
+from pathlib import Path
+from typing import Union
+from contextlib import contextmanager
 
+from mlflow.environment_variables import MLFLOW_TRACKING_AWS_SIGV4
 from mlflow.store.tracking import DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH
 from mlflow.store.db.db_types import DATABASE_ENGINES
 from mlflow.store.tracking.file_store import FileStore
@@ -28,6 +32,7 @@ _TRACKING_SERVER_CERT_PATH_ENV_VAR = "MLFLOW_TRACKING_SERVER_CERT_PATH"
 # see https://requests.readthedocs.io/en/master/api/
 _TRACKING_CLIENT_CERT_PATH_ENV_VAR = "MLFLOW_TRACKING_CLIENT_CERT_PATH"
 
+_logger = logging.getLogger(__name__)
 _tracking_uri = None
 
 
@@ -38,7 +43,7 @@ def is_tracking_uri_set():
     return False
 
 
-def set_tracking_uri(uri: str) -> None:
+def set_tracking_uri(uri: Union[str, Path]) -> None:
     """
     Set the tracking server URI. This does not affect the
     currently active run (if one exists), but takes effect for successive runs.
@@ -52,6 +57,7 @@ def set_tracking_uri(uri: str) -> None:
                   Databricks CLI
                   `profile <https://github.com/databricks/databricks-cli#installation>`_,
                   "databricks://<profileName>".
+                - A :py:class:`pathlib.Path` instance
 
     .. code-block:: python
         :caption: Example
@@ -67,10 +73,36 @@ def set_tracking_uri(uri: str) -> None:
 
         Current tracking uri: file:///tmp/my_tracking
     """
+    if isinstance(uri, Path):
+        # On Windows with Python3.7 (https://bugs.python.org/issue38671)
+        # .resolve() doesn't return the absolute path if the directory doesn't exist
+        # so we're calling .absolute() first to get the absolute path on Windows,
+        # then .resolve() to clean the path
+        uri = uri.absolute().resolve().as_uri()
     global _tracking_uri
     _tracking_uri = uri
 
 
+@contextmanager
+def _use_tracking_uri(uri: str, local_store_root_path: str = None) -> None:
+    """
+    Similar to `mlflow.tracking.set_tracking_uri` function but return a context manager.
+    :param uri: tracking URI to use.
+    :param local_store_root_path: the local store root path for the tracking URI.
+    """
+    global _tracking_uri
+    cwd = os.getcwd()
+    old_tracking_uri = _tracking_uri
+    try:
+        if local_store_root_path is not None:
+            os.chdir(local_store_root_path)
+        _tracking_uri = uri
+        yield
+    finally:
+        _tracking_uri = old_tracking_uri
+        os.chdir(cwd)
+
+
 def _resolve_tracking_uri(tracking_uri=None):
     return tracking_uri or get_tracking_uri()
 
@@ -123,6 +155,7 @@ def _get_default_host_creds(store_uri):
         username=os.environ.get(_TRACKING_USERNAME_ENV_VAR),
         password=os.environ.get(_TRACKING_PASSWORD_ENV_VAR),
         token=os.environ.get(_TRACKING_TOKEN_ENV_VAR),
+        aws_sigv4=MLFLOW_TRACKING_AWS_SIGV4.get(),
         ignore_tls_verification=os.environ.get(_TRACKING_INSECURE_TLS_ENV_VAR) == "true",
         client_cert_path=os.environ.get(_TRACKING_CLIENT_CERT_PATH_ENV_VAR),
         server_cert_path=os.environ.get(_TRACKING_SERVER_CERT_PATH_ENV_VAR),
@@ -170,10 +203,10 @@ def _get_git_url_if_present(uri):
     try:
         from git import Repo, InvalidGitRepositoryError, GitCommandNotFound, NoSuchPathError
     except ImportError as e:
-        print(
-            "Notice: failed to import Git (the git executable is probably not on your PATH),"
-            " so Git SHA is not available. Error: %s" % e,
-            file=sys.stderr,
+        _logger.warning(
+            "Failed to import Git (the git executable is probably not on your PATH),"
+            " so Git SHA is not available. Error: %s",
+            e,
         )
         return uri
     try:
