@@ -139,6 +139,7 @@ INSTALL_MLFLOW = click.option(
 HOST = click.option(
     "--host",
     "-h",
+    envvar="MLFLOW_HOST",
     metavar="HOST",
     default="127.0.0.1",
     help="The network address to listen on (default: 127.0.0.1). "
@@ -146,7 +147,13 @@ HOST = click.option(
     "server from other machines.",
 )
 
-PORT = click.option("--port", "-p", default=5000, help="The port to listen on (default: 5000).")
+PORT = click.option(
+    "--port",
+    "-p",
+    envvar="MLFLOW_PORT",
+    default=5000,
+    help="The port to listen on (default: 5000).",
+)
 
 TIMEOUT = click.option(
     "--timeout", "-t", help="Timeout in seconds to serve a request (default: 60)."
@@ -156,6 +163,7 @@ TIMEOUT = click.option(
 WORKERS = click.option(
     "--workers",
     "-w",
+    envvar="MLFLOW_WORKERS",
     default=None,
     help="Number of gunicorn worker processes to handle requests (default: 4).",
 )
@@ -169,6 +177,7 @@ ENABLE_MLSERVER = click.option(
 
 ARTIFACTS_DESTINATION = click.option(
     "--artifacts-destination",
+    envvar="MLFLOW_ARTIFACTS_DESTINATION",
     metavar="URI",
     default="./mlartifacts",
     help=(
@@ -181,6 +190,7 @@ ARTIFACTS_DESTINATION = click.option(
 
 SERVE_ARTIFACTS = click.option(
     "--serve-artifacts",
+    envvar="MLFLOW_SERVE_ARTIFACTS",
     is_flag=True,
     default=False,
     help="If specified, enables serving of artifact uploads, downloads, and list requests "
