@@ -1,13 +1,12 @@
-import sys
 import posixpath
 import urllib.parse
+import pathlib
 
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE
 from mlflow.store.db.db_types import DATABASE_ENGINES
-from mlflow.store.tracking import DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH, DEFAULT_ARTIFACTS_URI
 from mlflow.utils.validation import _validate_db_type_string
-from mlflow.utils.logging_utils import eprint
+from mlflow.utils.os import is_windows
 
 _INVALID_DB_URI_MSG = (
     "Please refer to https://mlflow.org/docs/latest/tracking.html#storage for "
@@ -20,8 +19,33 @@ _DBFS_HDFS_URI_PREFIX = "dbfs:/"
 
 def is_local_uri(uri):
     """Returns true if this is a local file path (/foo or file:/foo)."""
-    scheme = urllib.parse.urlparse(uri).scheme
-    return uri != "databricks" and (scheme == "" or scheme == "file")
+    if uri == "databricks":
+        return False
+
+    if is_windows() and uri.startswith("\\\\"):
+        # windows network drive path looks like: "\\<server name>\path\..."
+        return False
+
+    parsed_uri = urllib.parse.urlparse(uri)
+    if parsed_uri.hostname and not (
+        parsed_uri.hostname == "."
+        or parsed_uri.hostname.startswith("localhost")
+        or parsed_uri.hostname.startswith("127.0.0.1")
+    ):
+        return False
+
+    scheme = parsed_uri.scheme
+    if scheme == "" or scheme == "file":
+        return True
+
+    if is_windows() and len(scheme) == 1 and scheme.lower() == pathlib.Path(uri).drive.lower()[0]:
+        return True
+
+    return False
+
+
+def is_file_uri(uri):
+    return urllib.parse.urlparse(uri).scheme == "file"
 
 
 def is_http_uri(uri):
@@ -255,19 +279,6 @@ def is_databricks_model_registry_artifacts_uri(artifact_uri):
     return artifact_uri_path.startswith(_MODEL_REGISTRY_ARTIFACT_URI)
 
 
-def construct_run_url(hostname, experiment_id, run_id, workspace_id=None):
-    if not hostname or not experiment_id or not run_id:
-        raise MlflowException(
-            "Hostname, experiment ID, and run ID are all required to construct a run URL"
-        )
-    prefix = hostname
-    if workspace_id and workspace_id != "0":
-        prefix += "?o=" + workspace_id
-    return prefix + "#mlflow/experiments/{experiment_id}/runs/{run_id}".format(
-        experiment_id=experiment_id, run_id=run_id
-    )
-
-
 def is_valid_dbfs_uri(uri):
     parsed = urllib.parse.urlparse(uri)
     if parsed.scheme != "dbfs":
@@ -297,22 +308,3 @@ def dbfs_hdfs_uri_to_fuse_path(dbfs_uri):
         )
 
     return _DBFS_FUSE_PREFIX + dbfs_uri[len(_DBFS_HDFS_URI_PREFIX) :]
-
-
-def resolve_default_artifact_root(
-    serve_artifacts, default_artifact_root, backend_store_uri, resolve_to_local=False
-):
-    if serve_artifacts and not default_artifact_root:
-        default_artifact_root = DEFAULT_ARTIFACTS_URI
-    elif not serve_artifacts and not default_artifact_root:
-        if is_local_uri(backend_store_uri):
-            default_artifact_root = backend_store_uri
-        elif resolve_to_local:
-            default_artifact_root = DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH
-        else:
-            eprint(
-                "Option 'default-artifact-root' is required, when backend store is not "
-                "local file based."
-            )
-            sys.exit(1)
-    return default_artifact_root
